==> camitk_3.2.2.orig.tar.gz: camitk-3.2.2-Source/modeling/components/physicalmodel/MultiComponentDCPopup.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef MULTICOMPONENTDCPOPUP_H
#define MULTICOMPONENTDCPOPUP_H

#include <ComponentPopupMenu.h>

/** The popup menu of the multi component data component.
  * Allows to do different things directly from the DC popup.
  *
 
  */
class MultiComponentDCPopup : public camitk::ComponentPopupMenu  {

Q_OBJECT

public:
	MultiComponentDCPopup(camitk::Component *, QWidget*);

public slots:
  /** This slot allows you to create a new multi component inside this one
   */
  void addNewMultiComponent();
  /** This slot allows you to create a new structural component inside this one
   */
  void addNewStructuralComponent();
};

#endif

==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/modeling/components/physicalmodel/MultiComponentDCPopup.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef MULTICOMPONENTDCPOPUP_H
#define MULTICOMPONENTDCPOPUP_H

#include <ComponentPopupMenu.h>

/**
 * @ingroup group_cepmodeling_components_physicalmodel
 * 
 * @brief
 * The popup menu of the multi component data component.
  * Allows one to do different things directly from the DC popup.
 * 
 **/
class MultiComponentDCPopup : public camitk::ComponentPopupMenu  {

Q_OBJECT

public:
	MultiComponentDCPopup(camitk::Component *, QWidget*);

public slots:
  /** This slot allows you to create a new multi component inside this one
   */
  void addNewMultiComponent();
  /** This slot allows you to create a new structural component inside this one
   */
  void addNewStructuralComponent();
};

#endif
